@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,14 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.bigquery.logging.v1",
@@ -80,61 +78,80 @@ class AuditData(proto.Message):
     Attributes:
         table_insert_request (google.cloud.bigquery_logging_v1.types.TableInsertRequest):
             Table insert request.
+
             This field is a member of `oneof`_ ``request``.
         table_update_request (google.cloud.bigquery_logging_v1.types.TableUpdateRequest):
             Table update request.
+
             This field is a member of `oneof`_ ``request``.
         dataset_list_request (google.cloud.bigquery_logging_v1.types.DatasetListRequest):
             Dataset list request.
+
             This field is a member of `oneof`_ ``request``.
         dataset_insert_request (google.cloud.bigquery_logging_v1.types.DatasetInsertRequest):
             Dataset insert request.
+
             This field is a member of `oneof`_ ``request``.
         dataset_update_request (google.cloud.bigquery_logging_v1.types.DatasetUpdateRequest):
             Dataset update request.
+
             This field is a member of `oneof`_ ``request``.
         job_insert_request (google.cloud.bigquery_logging_v1.types.JobInsertRequest):
             Job insert request.
+
             This field is a member of `oneof`_ ``request``.
         job_query_request (google.cloud.bigquery_logging_v1.types.JobQueryRequest):
             Job query request.
+
             This field is a member of `oneof`_ ``request``.
         job_get_query_results_request (google.cloud.bigquery_logging_v1.types.JobGetQueryResultsRequest):
             Job get query results request.
+
             This field is a member of `oneof`_ ``request``.
         table_data_list_request (google.cloud.bigquery_logging_v1.types.TableDataListRequest):
             Table data-list request.
+
             This field is a member of `oneof`_ ``request``.
         set_iam_policy_request (google.iam.v1.iam_policy_pb2.SetIamPolicyRequest):
             Iam policy request.
+
             This field is a member of `oneof`_ ``request``.
         table_insert_response (google.cloud.bigquery_logging_v1.types.TableInsertResponse):
             Table insert response.
+
             This field is a member of `oneof`_ ``response``.
         table_update_response (google.cloud.bigquery_logging_v1.types.TableUpdateResponse):
             Table update response.
+
             This field is a member of `oneof`_ ``response``.
         dataset_insert_response (google.cloud.bigquery_logging_v1.types.DatasetInsertResponse):
             Dataset insert response.
+
             This field is a member of `oneof`_ ``response``.
         dataset_update_response (google.cloud.bigquery_logging_v1.types.DatasetUpdateResponse):
             Dataset update response.
+
             This field is a member of `oneof`_ ``response``.
         job_insert_response (google.cloud.bigquery_logging_v1.types.JobInsertResponse):
             Job insert response.
+
             This field is a member of `oneof`_ ``response``.
         job_query_response (google.cloud.bigquery_logging_v1.types.JobQueryResponse):
             Job query response.
+
             This field is a member of `oneof`_ ``response``.
         job_get_query_results_response (google.cloud.bigquery_logging_v1.types.JobGetQueryResultsResponse):
             Job get query results response.
+
             This field is a member of `oneof`_ ``response``.
         job_query_done_response (google.cloud.bigquery_logging_v1.types.JobQueryDoneResponse):
             Deprecated: Job query-done response. Use this
             information for usage analysis.
+
             This field is a member of `oneof`_ ``response``.
         policy_response (google.iam.v1.policy_pb2.Policy):
             Iam Policy.
+
             This field is a member of `oneof`_ ``response``.
         job_completed_event (google.cloud.bigquery_logging_v1.types.JobCompletedEvent):
             A job completion event.
@@ -143,31 +160,58 @@ class AuditData(proto.Message):
     """
 
     table_insert_request = proto.Field(
-        proto.MESSAGE, number=1, oneof="request", message="TableInsertRequest",
+        proto.MESSAGE,
+        number=1,
+        oneof="request",
+        message="TableInsertRequest",
     )
     table_update_request = proto.Field(
-        proto.MESSAGE, number=16, oneof="request", message="TableUpdateRequest",
+        proto.MESSAGE,
+        number=16,
+        oneof="request",
+        message="TableUpdateRequest",
     )
     dataset_list_request = proto.Field(
-        proto.MESSAGE, number=2, oneof="request", message="DatasetListRequest",
+        proto.MESSAGE,
+        number=2,
+        oneof="request",
+        message="DatasetListRequest",
     )
     dataset_insert_request = proto.Field(
-        proto.MESSAGE, number=3, oneof="request", message="DatasetInsertRequest",
+        proto.MESSAGE,
+        number=3,
+        oneof="request",
+        message="DatasetInsertRequest",
     )
     dataset_update_request = proto.Field(
-        proto.MESSAGE, number=4, oneof="request", message="DatasetUpdateRequest",
+        proto.MESSAGE,
+        number=4,
+        oneof="request",
+        message="DatasetUpdateRequest",
     )
     job_insert_request = proto.Field(
-        proto.MESSAGE, number=5, oneof="request", message="JobInsertRequest",
+        proto.MESSAGE,
+        number=5,
+        oneof="request",
+        message="JobInsertRequest",
     )
     job_query_request = proto.Field(
-        proto.MESSAGE, number=6, oneof="request", message="JobQueryRequest",
+        proto.MESSAGE,
+        number=6,
+        oneof="request",
+        message="JobQueryRequest",
     )
     job_get_query_results_request = proto.Field(
-        proto.MESSAGE, number=7, oneof="request", message="JobGetQueryResultsRequest",
+        proto.MESSAGE,
+        number=7,
+        oneof="request",
+        message="JobGetQueryResultsRequest",
     )
     table_data_list_request = proto.Field(
-        proto.MESSAGE, number=8, oneof="request", message="TableDataListRequest",
+        proto.MESSAGE,
+        number=8,
+        oneof="request",
+        message="TableDataListRequest",
     )
     set_iam_policy_request = proto.Field(
         proto.MESSAGE,
@@ -176,22 +220,40 @@ class AuditData(proto.Message):
         message=iam_policy_pb2.SetIamPolicyRequest,
     )
     table_insert_response = proto.Field(
-        proto.MESSAGE, number=9, oneof="response", message="TableInsertResponse",
+        proto.MESSAGE,
+        number=9,
+        oneof="response",
+        message="TableInsertResponse",
     )
     table_update_response = proto.Field(
-        proto.MESSAGE, number=10, oneof="response", message="TableUpdateResponse",
+        proto.MESSAGE,
+        number=10,
+        oneof="response",
+        message="TableUpdateResponse",
     )
     dataset_insert_response = proto.Field(
-        proto.MESSAGE, number=11, oneof="response", message="DatasetInsertResponse",
+        proto.MESSAGE,
+        number=11,
+        oneof="response",
+        message="DatasetInsertResponse",
     )
     dataset_update_response = proto.Field(
-        proto.MESSAGE, number=12, oneof="response", message="DatasetUpdateResponse",
+        proto.MESSAGE,
+        number=12,
+        oneof="response",
+        message="DatasetUpdateResponse",
     )
     job_insert_response = proto.Field(
-        proto.MESSAGE, number=18, oneof="response", message="JobInsertResponse",
+        proto.MESSAGE,
+        number=18,
+        oneof="response",
+        message="JobInsertResponse",
     )
     job_query_response = proto.Field(
-        proto.MESSAGE, number=13, oneof="response", message="JobQueryResponse",
+        proto.MESSAGE,
+        number=13,
+        oneof="response",
+        message="JobQueryResponse",
     )
     job_get_query_results_response = proto.Field(
         proto.MESSAGE,
@@ -200,16 +262,26 @@ class AuditData(proto.Message):
         message="JobGetQueryResultsResponse",
     )
     job_query_done_response = proto.Field(
-        proto.MESSAGE, number=15, oneof="response", message="JobQueryDoneResponse",
+        proto.MESSAGE,
+        number=15,
+        oneof="response",
+        message="JobQueryDoneResponse",
     )
     policy_response = proto.Field(
-        proto.MESSAGE, number=21, oneof="response", message=policy_pb2.Policy,
+        proto.MESSAGE,
+        number=21,
+        oneof="response",
+        message=policy_pb2.Policy,
     )
     job_completed_event = proto.Field(
-        proto.MESSAGE, number=17, message="JobCompletedEvent",
+        proto.MESSAGE,
+        number=17,
+        message="JobCompletedEvent",
     )
     table_data_read_events = proto.RepeatedField(
-        proto.MESSAGE, number=19, message="TableDataReadEvent",
+        proto.MESSAGE,
+        number=19,
+        message="TableDataReadEvent",
     )
 
 
@@ -221,7 +293,11 @@ class TableInsertRequest(proto.Message):
             The new table.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Table",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Table",
+    )
 
 
 class TableUpdateRequest(proto.Message):
@@ -232,7 +308,11 @@ class TableUpdateRequest(proto.Message):
             The table to be updated.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Table",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Table",
+    )
 
 
 class TableInsertResponse(proto.Message):
@@ -243,7 +323,11 @@ class TableInsertResponse(proto.Message):
             Final state of the inserted table.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Table",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Table",
+    )
 
 
 class TableUpdateResponse(proto.Message):
@@ -254,7 +338,11 @@ class TableUpdateResponse(proto.Message):
             Final state of the updated table.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Table",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Table",
+    )
 
 
 class DatasetListRequest(proto.Message):
@@ -266,7 +354,10 @@ class DatasetListRequest(proto.Message):
             hidden ones.
     """
 
-    list_all = proto.Field(proto.BOOL, number=1,)
+    list_all = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
 
 
 class DatasetInsertRequest(proto.Message):
@@ -277,7 +368,11 @@ class DatasetInsertRequest(proto.Message):
             The dataset to be inserted.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Dataset",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Dataset",
+    )
 
 
 class DatasetInsertResponse(proto.Message):
@@ -288,7 +383,11 @@ class DatasetInsertResponse(proto.Message):
             Final state of the inserted dataset.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Dataset",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Dataset",
+    )
 
 
 class DatasetUpdateRequest(proto.Message):
@@ -299,7 +398,11 @@ class DatasetUpdateRequest(proto.Message):
             The dataset to be updated.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Dataset",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Dataset",
+    )
 
 
 class DatasetUpdateResponse(proto.Message):
@@ -310,7 +413,11 @@ class DatasetUpdateResponse(proto.Message):
             Final state of the updated dataset.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Dataset",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Dataset",
+    )
 
 
 class JobInsertRequest(proto.Message):
@@ -321,7 +428,11 @@ class JobInsertRequest(proto.Message):
             Job insert request.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Job",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Job",
+    )
 
 
 class JobInsertResponse(proto.Message):
@@ -332,7 +443,11 @@ class JobInsertResponse(proto.Message):
             Job insert response.
     """
 
-    resource = proto.Field(proto.MESSAGE, number=1, message="Job",)
+    resource = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Job",
+    )
 
 
 class JobQueryRequest(proto.Message):
@@ -353,11 +468,27 @@ class JobQueryRequest(proto.Message):
             check that it would run.
     """
 
-    query = proto.Field(proto.STRING, number=1,)
-    max_results = proto.Field(proto.UINT32, number=2,)
-    default_dataset = proto.Field(proto.MESSAGE, number=3, message="DatasetName",)
-    project_id = proto.Field(proto.STRING, number=4,)
-    dry_run = proto.Field(proto.BOOL, number=5,)
+    query = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    max_results = proto.Field(
+        proto.UINT32,
+        number=2,
+    )
+    default_dataset = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="DatasetName",
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    dry_run = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
 
 
 class JobQueryResponse(proto.Message):
@@ -371,8 +502,15 @@ class JobQueryResponse(proto.Message):
             Information about the queried job.
     """
 
-    total_results = proto.Field(proto.UINT64, number=1,)
-    job = proto.Field(proto.MESSAGE, number=2, message="Job",)
+    total_results = proto.Field(
+        proto.UINT64,
+        number=1,
+    )
+    job = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Job",
+    )
 
 
 class JobGetQueryResultsRequest(proto.Message):
@@ -385,8 +523,14 @@ class JobGetQueryResultsRequest(proto.Message):
             Zero-based row number at which to start.
     """
 
-    max_results = proto.Field(proto.UINT32, number=1,)
-    start_row = proto.Field(proto.UINT64, number=2,)
+    max_results = proto.Field(
+        proto.UINT32,
+        number=1,
+    )
+    start_row = proto.Field(
+        proto.UINT64,
+        number=2,
+    )
 
 
 class JobGetQueryResultsResponse(proto.Message):
@@ -401,8 +545,15 @@ class JobGetQueryResultsResponse(proto.Message):
             ``job.status.errorResult`` is also present.
     """
 
-    total_results = proto.Field(proto.UINT64, number=1,)
-    job = proto.Field(proto.MESSAGE, number=2, message="Job",)
+    total_results = proto.Field(
+        proto.UINT64,
+        number=1,
+    )
+    job = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Job",
+    )
 
 
 class JobQueryDoneResponse(proto.Message):
@@ -414,7 +565,11 @@ class JobQueryDoneResponse(proto.Message):
             ``job.status.state`` is ``DONE``.
     """
 
-    job = proto.Field(proto.MESSAGE, number=1, message="Job",)
+    job = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Job",
+    )
 
 
 class JobCompletedEvent(proto.Message):
@@ -427,8 +582,15 @@ class JobCompletedEvent(proto.Message):
             Job information.
     """
 
-    event_name = proto.Field(proto.STRING, number=1,)
-    job = proto.Field(proto.MESSAGE, number=2, message="Job",)
+    event_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Job",
+    )
 
 
 class TableDataReadEvent(proto.Message):
@@ -446,8 +608,15 @@ class TableDataReadEvent(proto.Message):
             open a bug in the BigQuery issue tracker.
     """
 
-    table_name = proto.Field(proto.MESSAGE, number=1, message="TableName",)
-    referenced_fields = proto.RepeatedField(proto.STRING, number=2,)
+    table_name = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="TableName",
+    )
+    referenced_fields = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class TableDataListRequest(proto.Message):
@@ -460,8 +629,14 @@ class TableDataListRequest(proto.Message):
             Maximum number of results to return.
     """
 
-    start_row = proto.Field(proto.UINT64, number=1,)
-    max_results = proto.Field(proto.UINT32, number=2,)
+    start_row = proto.Field(
+        proto.UINT64,
+        number=1,
+    )
+    max_results = proto.Field(
+        proto.UINT32,
+        number=2,
+    )
 
 
 class Table(proto.Message):
@@ -498,17 +673,50 @@ class Table(proto.Message):
             non-default encryption is used.
     """
 
-    table_name = proto.Field(proto.MESSAGE, number=1, message="TableName",)
-    info = proto.Field(proto.MESSAGE, number=2, message="TableInfo",)
-    schema_json = proto.Field(proto.STRING, number=8,)
-    view = proto.Field(proto.MESSAGE, number=4, message="TableViewDefinition",)
-    expire_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    create_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
+    table_name = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="TableName",
+    )
+    info = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="TableInfo",
+    )
+    schema_json = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    view = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="TableViewDefinition",
+    )
+    expire_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
     truncate_time = proto.Field(
-        proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=timestamp_pb2.Timestamp,
+    )
+    encryption = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message="EncryptionInfo",
     )
-    update_time = proto.Field(proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,)
-    encryption = proto.Field(proto.MESSAGE, number=10, message="EncryptionInfo",)
 
 
 class TableInfo(proto.Message):
@@ -522,13 +730,23 @@ class TableInfo(proto.Message):
             A long description, perhaps several
             paragraphs, describing the table contents in
             detail.
-        labels (Sequence[google.cloud.bigquery_logging_v1.types.TableInfo.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels provided for the table.
     """
 
-    friendly_name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=3,)
+    friendly_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
 
 
 class TableViewDefinition(proto.Message):
@@ -539,7 +757,10 @@ class TableViewDefinition(proto.Message):
             SQL query defining the view.
     """
 
-    query = proto.Field(proto.STRING, number=1,)
+    query = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class Dataset(proto.Message):
@@ -565,13 +786,35 @@ class Dataset(proto.Message):
             is empty, there is no default table expiration time.
     """
 
-    dataset_name = proto.Field(proto.MESSAGE, number=1, message="DatasetName",)
-    info = proto.Field(proto.MESSAGE, number=2, message="DatasetInfo",)
-    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    acl = proto.Field(proto.MESSAGE, number=6, message="BigQueryAcl",)
+    dataset_name = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="DatasetName",
+    )
+    info = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="DatasetInfo",
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    acl = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="BigQueryAcl",
+    )
     default_table_expire_duration = proto.Field(
-        proto.MESSAGE, number=8, message=duration_pb2.Duration,
+        proto.MESSAGE,
+        number=8,
+        message=duration_pb2.Duration,
     )
 
 
@@ -586,13 +829,23 @@ class DatasetInfo(proto.Message):
             A long description, perhaps several
             paragraphs, describing the dataset contents in
             detail.
-        labels (Sequence[google.cloud.bigquery_logging_v1.types.DatasetInfo.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels provided for the dataset.
     """
 
-    friendly_name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=3,)
+    friendly_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
 
 
 class BigQueryAcl(proto.Message):
@@ -626,14 +879,37 @@ class BigQueryAcl(proto.Message):
                 Grants access to a BigQuery View.
         """
 
-        role = proto.Field(proto.STRING, number=1,)
-        group_email = proto.Field(proto.STRING, number=2,)
-        user_email = proto.Field(proto.STRING, number=3,)
-        domain = proto.Field(proto.STRING, number=4,)
-        special_group = proto.Field(proto.STRING, number=5,)
-        view_name = proto.Field(proto.MESSAGE, number=6, message="TableName",)
+        role = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        group_email = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        user_email = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        domain = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        special_group = proto.Field(
+            proto.STRING,
+            number=5,
+        )
+        view_name = proto.Field(
+            proto.MESSAGE,
+            number=6,
+            message="TableName",
+        )
 
-    entries = proto.RepeatedField(proto.MESSAGE, number=1, message=Entry,)
+    entries = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=Entry,
+    )
 
 
 class Job(proto.Message):
@@ -650,12 +926,26 @@ class Job(proto.Message):
             Job statistics.
     """
 
-    job_name = proto.Field(proto.MESSAGE, number=1, message="JobName",)
+    job_name = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="JobName",
+    )
     job_configuration = proto.Field(
-        proto.MESSAGE, number=2, message="JobConfiguration",
+        proto.MESSAGE,
+        number=2,
+        message="JobConfiguration",
+    )
+    job_status = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="JobStatus",
+    )
+    job_statistics = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="JobStatistics",
     )
-    job_status = proto.Field(proto.MESSAGE, number=3, message="JobStatus",)
-    job_statistics = proto.Field(proto.MESSAGE, number=4, message="JobStatistics",)
 
 
 class JobConfiguration(proto.Message):
@@ -673,20 +963,24 @@ class JobConfiguration(proto.Message):
     Attributes:
         query (google.cloud.bigquery_logging_v1.types.JobConfiguration.Query):
             Query job information.
+
             This field is a member of `oneof`_ ``configuration``.
         load (google.cloud.bigquery_logging_v1.types.JobConfiguration.Load):
             Load job information.
+
             This field is a member of `oneof`_ ``configuration``.
         extract (google.cloud.bigquery_logging_v1.types.JobConfiguration.Extract):
             Extract job information.
+
             This field is a member of `oneof`_ ``configuration``.
         table_copy (google.cloud.bigquery_logging_v1.types.JobConfiguration.TableCopy):
             TableCopy job information.
+
             This field is a member of `oneof`_ ``configuration``.
         dry_run (bool):
             If true, don't actually run the job. Just
             check that it would run.
-        labels (Sequence[google.cloud.bigquery_logging_v1.types.JobConfiguration.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels provided for the job.
     """
 
@@ -722,19 +1016,46 @@ class JobConfiguration(proto.Message):
                 CREATE_MODEL..)
         """
 
-        query = proto.Field(proto.STRING, number=1,)
-        destination_table = proto.Field(proto.MESSAGE, number=2, message="TableName",)
-        create_disposition = proto.Field(proto.STRING, number=3,)
-        write_disposition = proto.Field(proto.STRING, number=4,)
-        default_dataset = proto.Field(proto.MESSAGE, number=5, message="DatasetName",)
+        query = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        destination_table = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message="TableName",
+        )
+        create_disposition = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        write_disposition = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        default_dataset = proto.Field(
+            proto.MESSAGE,
+            number=5,
+            message="DatasetName",
+        )
         table_definitions = proto.RepeatedField(
-            proto.MESSAGE, number=6, message="TableDefinition",
+            proto.MESSAGE,
+            number=6,
+            message="TableDefinition",
+        )
+        query_priority = proto.Field(
+            proto.STRING,
+            number=7,
         )
-        query_priority = proto.Field(proto.STRING, number=7,)
         destination_table_encryption = proto.Field(
-            proto.MESSAGE, number=8, message="EncryptionInfo",
+            proto.MESSAGE,
+            number=8,
+            message="EncryptionInfo",
+        )
+        statement_type = proto.Field(
+            proto.STRING,
+            number=9,
         )
-        statement_type = proto.Field(proto.STRING, number=9,)
 
     class Load(proto.Message):
         r"""Describes a load job, which loads data from an external
@@ -760,13 +1081,31 @@ class JobConfiguration(proto.Message):
                 non-default encryption is used.
         """
 
-        source_uris = proto.RepeatedField(proto.STRING, number=1,)
-        schema_json = proto.Field(proto.STRING, number=6,)
-        destination_table = proto.Field(proto.MESSAGE, number=3, message="TableName",)
-        create_disposition = proto.Field(proto.STRING, number=4,)
-        write_disposition = proto.Field(proto.STRING, number=5,)
+        source_uris = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
+        schema_json = proto.Field(
+            proto.STRING,
+            number=6,
+        )
+        destination_table = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message="TableName",
+        )
+        create_disposition = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        write_disposition = proto.Field(
+            proto.STRING,
+            number=5,
+        )
         destination_table_encryption = proto.Field(
-            proto.MESSAGE, number=7, message="EncryptionInfo",
+            proto.MESSAGE,
+            number=7,
+            message="EncryptionInfo",
         )
 
     class Extract(proto.Message):
@@ -781,8 +1120,15 @@ class JobConfiguration(proto.Message):
                 The source table.
         """
 
-        destination_uris = proto.RepeatedField(proto.STRING, number=1,)
-        source_table = proto.Field(proto.MESSAGE, number=2, message="TableName",)
+        destination_uris = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
+        source_table = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message="TableName",
+        )
 
     class TableCopy(proto.Message):
         r"""Describes a copy job, which copies an existing table to
@@ -805,25 +1151,62 @@ class JobConfiguration(proto.Message):
         """
 
         source_tables = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="TableName",
+            proto.MESSAGE,
+            number=1,
+            message="TableName",
+        )
+        destination_table = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message="TableName",
+        )
+        create_disposition = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        write_disposition = proto.Field(
+            proto.STRING,
+            number=4,
         )
-        destination_table = proto.Field(proto.MESSAGE, number=2, message="TableName",)
-        create_disposition = proto.Field(proto.STRING, number=3,)
-        write_disposition = proto.Field(proto.STRING, number=4,)
         destination_table_encryption = proto.Field(
-            proto.MESSAGE, number=5, message="EncryptionInfo",
+            proto.MESSAGE,
+            number=5,
+            message="EncryptionInfo",
         )
 
-    query = proto.Field(proto.MESSAGE, number=5, oneof="configuration", message=Query,)
-    load = proto.Field(proto.MESSAGE, number=6, oneof="configuration", message=Load,)
+    query = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        oneof="configuration",
+        message=Query,
+    )
+    load = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        oneof="configuration",
+        message=Load,
+    )
     extract = proto.Field(
-        proto.MESSAGE, number=7, oneof="configuration", message=Extract,
+        proto.MESSAGE,
+        number=7,
+        oneof="configuration",
+        message=Extract,
     )
     table_copy = proto.Field(
-        proto.MESSAGE, number=8, oneof="configuration", message=TableCopy,
+        proto.MESSAGE,
+        number=8,
+        oneof="configuration",
+        message=TableCopy,
+    )
+    dry_run = proto.Field(
+        proto.BOOL,
+        number=9,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
     )
-    dry_run = proto.Field(proto.BOOL, number=9,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=3,)
 
 
 class TableDefinition(proto.Message):
@@ -837,8 +1220,14 @@ class TableDefinition(proto.Message):
             imported.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    source_uris = proto.RepeatedField(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    source_uris = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class JobStatus(proto.Message):
@@ -856,10 +1245,19 @@ class JobStatus(proto.Message):
             completed or was unsuccessful.
     """
 
-    state = proto.Field(proto.STRING, number=1,)
-    error = proto.Field(proto.MESSAGE, number=2, message=status_pb2.Status,)
+    state = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    error = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=status_pb2.Status,
+    )
     additional_errors = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=status_pb2.Status,
+        proto.MESSAGE,
+        number=3,
+        message=status_pb2.Status,
     )
 
 
@@ -917,36 +1315,84 @@ class JobStatistics(proto.Message):
 
         Attributes:
             name (str):
-                Reservation name or "unreserved" for on-
-                emand resources usage.
+                Reservation name or "unreserved" for
+                on-demand resources usage.
             slot_ms (int):
                 Total slot milliseconds used by the
                 reservation for a particular job.
         """
 
-        name = proto.Field(proto.STRING, number=1,)
-        slot_ms = proto.Field(proto.INT64, number=2,)
+        name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        slot_ms = proto.Field(
+            proto.INT64,
+            number=2,
+        )
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    start_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    total_processed_bytes = proto.Field(proto.INT64, number=4,)
-    total_billed_bytes = proto.Field(proto.INT64, number=5,)
-    billing_tier = proto.Field(proto.INT32, number=7,)
-    total_slot_ms = proto.Field(proto.INT64, number=8,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    total_processed_bytes = proto.Field(
+        proto.INT64,
+        number=4,
+    )
+    total_billed_bytes = proto.Field(
+        proto.INT64,
+        number=5,
+    )
+    billing_tier = proto.Field(
+        proto.INT32,
+        number=7,
+    )
+    total_slot_ms = proto.Field(
+        proto.INT64,
+        number=8,
+    )
     reservation_usage = proto.RepeatedField(
-        proto.MESSAGE, number=14, message=ReservationResourceUsage,
+        proto.MESSAGE,
+        number=14,
+        message=ReservationResourceUsage,
     )
     referenced_tables = proto.RepeatedField(
-        proto.MESSAGE, number=9, message="TableName",
+        proto.MESSAGE,
+        number=9,
+        message="TableName",
+    )
+    total_tables_processed = proto.Field(
+        proto.INT32,
+        number=10,
     )
-    total_tables_processed = proto.Field(proto.INT32, number=10,)
     referenced_views = proto.RepeatedField(
-        proto.MESSAGE, number=11, message="TableName",
+        proto.MESSAGE,
+        number=11,
+        message="TableName",
+    )
+    total_views_processed = proto.Field(
+        proto.INT32,
+        number=12,
+    )
+    query_output_row_count = proto.Field(
+        proto.INT64,
+        number=15,
+    )
+    total_load_output_bytes = proto.Field(
+        proto.INT64,
+        number=13,
     )
-    total_views_processed = proto.Field(proto.INT32, number=12,)
-    query_output_row_count = proto.Field(proto.INT64, number=15,)
-    total_load_output_bytes = proto.Field(proto.INT64, number=13,)
 
 
 class DatasetName(proto.Message):
@@ -959,8 +1405,14 @@ class DatasetName(proto.Message):
             The dataset ID within the project.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    dataset_id = proto.Field(proto.STRING, number=2,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dataset_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class TableName(proto.Message):
@@ -975,9 +1427,18 @@ class TableName(proto.Message):
             The table ID of the table within the dataset.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    dataset_id = proto.Field(proto.STRING, number=2,)
-    table_id = proto.Field(proto.STRING, number=3,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dataset_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    table_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class JobName(proto.Message):
@@ -992,9 +1453,18 @@ class JobName(proto.Message):
             The job location.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    job_id = proto.Field(proto.STRING, number=2,)
-    location = proto.Field(proto.STRING, number=3,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class EncryptionInfo(proto.Message):
@@ -1005,7 +1475,10 @@ class EncryptionInfo(proto.Message):
             unique identifier for cloud kms key
     """
 
-    kms_key_name = proto.Field(proto.STRING, number=1,)
+    kms_key_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
